NAME
Acme::PM:Dresden - A module for mostly educational purposes, although with useful functionality.
SYNOPSIS
use Acme::PM::Dresden;
ABOUT
This project is an educational collecting tank for any functions and/or experiments we (the Dresden Perl Mongers) need a place for.
Version 0.01, for instance, was an empty project, simply demonstrating the construction of a CPAN distribution.
Sometimes a useful module starts his live here as happened with TWikiClient.
See the modules Acme::PM::Dresden::TWikiClient, Acme::PM::Dresden::VQWikiClient and Acme::PM::Dresden::Convert::VQWiki2TWiki for first useful stuff.
METHODS
hello
Just returns a string that you can print out. It does not do the print itself.
AUTHOR
Dresden Perl Mongers <http://dresden-pm.org>
LICENSE
Copyright (c) 2005. Perl Mongers Dresden
All rights reserved. You can redistribute and/or modify
this bundle under the same terms as Perl itself.